@@ -2,13 +2,14 @@
 #'
 #' @description
 #' A string is defined as a scalar character vector.
+#' To check for vectors of arbitrary length, see \code{\link{checkCharacter}}.
 #'
 #' @templateVar fn String
 #' @template x
 #' @template na-handling
-#' @param na.ok [\code{logical(1)}]\cr
-#'  Are missing values allowed? Default is \code{FALSE}.
+#' @template na.ok
 #' @inheritParams checkCharacter
+#' @template null.ok
 #' @template checker
 #' @family scalars
 #' @export
@@ -16,16 +17,20 @@
 #' @examples
 #' testString("a")
 #' testString(letters)
-checkString = function(x, na.ok = FALSE, min.chars = NULL, pattern = NULL, fixed = NULL, ignore.case = FALSE) {
-  .Call(c_check_string, x, na.ok, min.chars) %and%
-  checkCharacterPattern(x, pattern, fixed, ignore.case)
+checkString = function(x, na.ok = FALSE, n.chars = NULL, min.chars = NULL, max.chars = NULL, pattern = NULL, fixed = NULL, ignore.case = FALSE, null.ok = FALSE) {
+  .Call(c_check_string, x, na.ok, n.chars, min.chars, max.chars, null.ok) %and%
+    checkCharacterPattern(x, pattern, fixed, ignore.case)
 }
 
+#' @export
+#' @rdname checkString
+check_string = checkString
+
 #' @export
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkString
-assertString = makeAssertionFunction(checkString)
+assertString = makeAssertionFunction(checkString, use.namespace = FALSE)
 
 #' @export
 #' @rdname checkString
@@ -44,4 +49,4 @@ test_string = testString
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkString
-expect_string = makeExpectationFunction(checkString)
+expect_string = makeExpectationFunction(checkString, use.namespace = FALSE)
